==> haskell-topograph-1.0.0.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 topograph
version:              1.0.0.1
visibility:           public
id:                   topograph-1.0.0.1-5XXcLjlvpoDD3xar8MiMJV
key:                  topograph-1.0.0.1-5XXcLjlvpoDD3xar8MiMJV
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  8d62d2b11bcbfa2922d04cee5f7263c2
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.0.1/site-local/topograph-1.0.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/topograph-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/topograph-1.0.0.1
hs-libraries:         HStopograph-1.0.0.1-5XXcLjlvpoDD3xar8MiMJV
depends:
    base-4.15.0.0 base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    base-orphans-0.8.4-3dHy2bt1s3BH2BfEbyyCdC containers-0.6.4.1
    vector-0.12.3.0-GI0lTgAWws2EpJyQa7KDn5

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-topograph-1.0.0.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-topograph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 topograph
version:              1.0.0.1
visibility:           public
id:                   topograph-1.0.0.1-6rrZha6TS1JK61zYxKXd84
key:                  topograph-1.0.0.1-6rrZha6TS1JK61zYxKXd84
license:              BSD-3-Clause
copyright:            (c) 2018-2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/topograph
synopsis:             Directed acyclic graphs.
description:
    Directed acyclic graphs can be sorted topographically.
    Existence of topographic ordering allows writing many graph algorithms efficiently.
    And many graphs, e.g. most dependency graphs are acyclic!

    There are some algorithms built-in: dfs, transpose, transitive closure,
    transitive reduction...
    Some algorithms even become not-so-hard to implement, like a longest path!

category:             Data, Graph
abi:                  e70dba28bfd109cae85bf9dd0da25d15
exposed:              True
exposed-modules:      Topograph
import-dirs:          /usr/lib/ghc-9.0.1/site-local/topograph-1.0.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/topograph-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/topograph-1.0.0.1
hs-libraries:         HStopograph-1.0.0.1-6rrZha6TS1JK61zYxKXd84
depends:
    base-4.15.0.0 base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    base-orphans-0.8.4-7HXGrYvuRnN62MKHDhd51W containers-0.6.4.1
    vector-0.12.3.1-KJ02XewdvWJHGa2GVFsQSX

haddock-interfaces:   /usr/share/doc/haskell-topograph/html/topograph.haddock
haddock-html:         /usr/share/doc/haskell-topograph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
